@@ -67,6 +67,9 @@ function battle_calcs.unit_attack_info(unit, cache)
             end
         end
 
+        -- [attack]number= defaults to zero; must be defined for battle_calcs.best_weapons()
+        a.number = a.number or 0
+
         table.insert(unit_info.attacks, a)
     end
 
