@@ -23,7 +23,7 @@ Limitations:
 import sys, re, copy
 keyPattern = re.compile('(\w+)(,\s?\w+)*\s*=')
 keySplit = re.compile(r'[=,\s]')
-tagPattern = re.compile(r'(^|(?<![\w\|\}]))(\[/?\+?[a-z].*?\])')
+tagPattern = re.compile(r'(^|(?<![\w|}]))(\[/?\+?[a-z _]+\])')
 macroOpenPattern = re.compile(r'(\{[^\s\}\{]*)')
 macroClosePattern = re.compile(r'\}')
 closeMacroType = 'end of macro'
@@ -96,12 +96,12 @@ class WmlIterator(object):
     empty and the filename is specified, lines will be read from the file.
 
     Note: if changes are made to lines while iterating, this may produce
-    unexpected results. In such case, seek() to the linenumber of a
+    unexpected results. In such case, seek() to the line number of a
     scope behind where changes were made.
 Important Attributes:
     lines - this is an internal list of all the physical lines
     scopes - this is an internal list of all open scopes (as iterators)
-             note: when retreiving an iterator from this list, always
+             note: when retrieving an iterator from this list, always
              use a copy to perform seek() or next(), and not the original
     element - the wml tag, key, or macro name for this logical line
               (in complex cases, this may be a tuple of elements...
@@ -235,8 +235,8 @@ Important Attributes:
         # first remove any lua strings
         beginquote = text.find('<<')
         while beginquote >= 0:
-            endquote = text.find('>>')
-            if endquote < -1:
+            endquote = text.find('>>', beginquote+2)
+            if endquote < 0:
                 text = text[:beginquote]
                 beginquote = -1 #terminate loop
             else:
@@ -361,7 +361,7 @@ Important Attributes:
 
     def ancestors(self):
         """Return a list of tags enclosing this location, outermost first."""
-        return tuple(map(lambda x: x.element, self.scopes))
+        return tuple([x.element for x in self.scopes])
 
     def hasNext(self):
         """Some loops may wish to check this method instead of calling next()
